@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.96 2005/01/22 19:27:14 davyd Exp $
+ $Id: battstat_applet.c,v 1.98 2005/02/27 18:11:14 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -296,7 +296,7 @@ allocate_battery_colours( void )
 static int instances;
 
 static const char *
-static_global_initialisation()
+static_global_initialisation(void)
 {
   const char *err;
 
@@ -312,7 +312,7 @@ static_global_initialisation()
 }
 
 static void
-static_global_teardown()
+static_global_teardown(void)
 {
   if( --instances )
     return;
@@ -1041,7 +1041,7 @@ change_background (PanelApplet *a,
 	gtk_widget_set_style (GTK_WIDGET (battstat->applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (battstat->applet), rc_style);
-	g_object_unref (rc_style);
+	gtk_rc_style_unref (rc_style);
 
 	switch (type) {
 		case PANEL_COLOR_BACKGROUND:
@@ -1059,6 +1059,7 @@ change_background (PanelApplet *a,
 				(pixmap);
 			gtk_widget_set_style (GTK_WIDGET (battstat->applet),
 					style);
+			g_object_unref (style);
 			break;
 
 		case PANEL_NO_BACKGROUND:
@@ -1102,7 +1103,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, ProgressData *battstat)
 
 /* Get our settings out of gconf.
  */
-void
+static void
 load_preferences(ProgressData *battstat)
 {
   PanelApplet *applet = PANEL_APPLET (battstat->applet);
