@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2001, 2002 Free Software Foundation
+ * GNOME CPUFreq Applet
+ * Copyright (C) 2004 Carlos Garcia Campos <carlosgc@gnome.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -20,5 +21,7 @@
 
 #include <gnome.h>
 
-gboolean   cpufreq_popup_show (GtkWidget *widget, GdkEventButton *event, gpointer gdata);
+#include "cpufreq-applet.h"
+
+gboolean cpufreq_popup_show (CPUFreqApplet *applet, guint32 time);
 
