@@ -39,8 +39,8 @@ typedef struct
 	GtkWidget   *hbox;
 	GtkWidget   **eyes;
 	guint        timeout_id;
-	gint pointer_last_x;
-	gint pointer_last_y;
+	gint 	    *pointer_last_x;
+	gint 	    *pointer_last_y;
 
 	/* Theme */
 	GdkPixbuf *eye_image;
@@ -70,7 +70,7 @@ void destroy_eyes (EyesApplet *eyes_applet);
 
 
 /* theme.c */
-void theme_dirs_create ();
+void theme_dirs_create (void);
 
 int load_theme    (EyesApplet        *eyes_applet,
 		   const gchar       *theme_dir);
