@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.52 2005/01/16 17:52:58 dcransto Exp $ */
+/* $Id: gweather-dialog.c,v 1.54 2005/02/24 09:01:53 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -530,8 +530,8 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       if (!panel_applet_gconf_get_bool (gw_applet->applet, "use_custom_radar_url", NULL))
       gtk_container_add (GTK_CONTAINER (radar_link_alignment), radar_link_btn);
 
-      gtk_signal_connect (GTK_OBJECT (radar_link_btn), "clicked",
-                          GTK_SIGNAL_FUNC (link_cb), NULL);
+      g_signal_connect (G_OBJECT (radar_link_btn), "clicked",
+                        G_CALLBACK (link_cb), NULL);
 
   }
 
@@ -577,7 +577,7 @@ void gweather_dialog_display_toggle (GWeatherApplet *gw_applet)
         gweather_dialog_close(gw_applet);
 }
 
-PangoFontDescription *get_system_monospace_font (void)
+static PangoFontDescription *get_system_monospace_font (void)
 {
     PangoFontDescription *desc = NULL;
     GConfClient *conf;
